import request from '@/utils/request'

// 查询企业科技研发信息汇总列表
export function listSummary(query) {
    return request({
        url: '/crmEnterpriseTechnologyRndSummary/findByPage',
        method: 'get',
        params: query
    })
}

// 查询企业科技研发信息汇总详细
export function getSummary(id) {
    return request({
        url: '/crmEnterpriseTechnologyRndSummary/' + id,
        method: 'get'
    })
}

// 新增企业科技研发信息汇总
export function addSummary(data) {
    return request({
        url: '/crmEnterpriseTechnologyRndSummary',
        method: 'post',
        data: data
    })
}

// 修改企业科技研发信息汇总
export function updateSummary(data) {
    return request({
        url: '/crmEnterpriseTechnologyRndSummary',
        method: 'put',
        data: data
    })
}

// 删除企业科技研发信息汇总
export function delSummary(id) {
    return request({
        url: '/crmEnterpriseTechnologyRndSummary/deleteAll',
        method: 'delete'
    })
}
// 批量删除行政许可
export function delSummaryBatch(ids) {
    console.log(ids);
    return request.post('/crmEnterpriseTechnologyRndSummary/delete',ids)
}