<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryRef" :inline="true" v-show="showSearch" label-width="68px">
      <el-form-item label="统一社会信用代码" label-width="200" prop="unifiedSocialCreditCode">
        <el-input
            v-model="queryParams.unifiedSocialCreditCode"
            placeholder="请输入统一社会信用代码"
            clearable
            @keyup.enter="handleQuery"
        />
      </el-form-item>
      <el-form-item label="企业名称" prop="enterpriseName">
        <el-input
            v-model="queryParams.enterpriseName"
            placeholder="请输入企业名称"
            clearable
            @keyup.enter="handleQuery"
        />
      </el-form-item>
<!--      <el-form-item label="是否属于国家级" prop="isNationalLevel">-->
<!--        <el-input-->
<!--            v-model="queryParams.isNationalLevel"-->
<!--            placeholder="请输入是否属于国家级"-->
<!--            clearable-->
<!--            @keyup.enter="handleQuery"-->
<!--        />-->
<!--      </el-form-item>-->
<!--      <el-form-item label="实验室建设" prop="labConstruction">-->
<!--        <el-input-->
<!--            v-model="queryParams.labConstruction"-->
<!--            placeholder="请输入实验室建设"-->
<!--            clearable-->
<!--            @keyup.enter="handleQuery"-->
<!--        />-->
<!--      </el-form-item>-->
<!--      <el-form-item label="政府资金支持" prop="governmentFundingSupport">-->
<!--        <el-input-->
<!--            v-model="queryParams.governmentFundingSupport"-->
<!--            placeholder="请输入政府资金支持"-->
<!--            clearable-->
<!--            @keyup.enter="handleQuery"-->
<!--        />-->
<!--      </el-form-item>-->
<!--      <el-form-item label="参与标准制定" prop="participationInStandards">-->
<!--        <el-input-->
<!--            v-model="queryParams.participationInStandards"-->
<!--            placeholder="请输入参与标准制定"-->
<!--            clearable-->
<!--            @keyup.enter="handleQuery"-->
<!--        />-->
<!--      </el-form-item>-->
<!--      <el-form-item label="人才认证" prop="talentCertification">-->
<!--        <el-input-->
<!--            v-model="queryParams.talentCertification"-->
<!--            placeholder="请输入人才认证"-->
<!--            clearable-->
<!--            @keyup.enter="handleQuery"-->
<!--        />-->
<!--      </el-form-item>-->
<!--      <el-form-item label="其他" prop="otherRelatedActivities">-->
<!--        <el-input-->
<!--            v-model="queryParams.otherRelatedActivities"-->
<!--            placeholder="请输入其他"-->
<!--            clearable-->
<!--            @keyup.enter="handleQuery"-->
<!--        />-->
<!--      </el-form-item>-->
      <el-form-item>
        <el-button type="primary" icon="Search" @click="handleQuery">搜索</el-button>
        <el-button icon="Refresh" @click="resetQuery">重置</el-button>
      </el-form-item>
      <el-form-item>
        <el-row :gutter="10" class="mb8">
          <!--      <el-col :span="1.5">-->
          <!--        <el-button-->
          <!--            type="primary"-->
          <!--            plain-->
          <!--            icon="Plus"-->
          <!--            @click="handleAdd"-->
          <!--            v-hasPermi="['basicData:summary:add']"-->
          <!--        >新增</el-button>-->
          <!--      </el-col>-->
          <!--      <el-col :span="1.5">-->
          <!--        <el-button-->
          <!--            type="success"-->
          <!--            plain-->
          <!--            icon="Edit"-->
          <!--            :disabled="single"-->
          <!--            @click="handleUpdate"-->
          <!--            v-hasPermi="['basicData:summary:edit']"-->
          <!--        >修改</el-button>-->
          <!--      </el-col>-->
          <el-col :span="1.5">
            <el-popconfirm
                title="你确定清除所有数据？"
                confirm-button-text="是的"
                cancel-button-text="不是"
                :icon="InfoFilled"
                icon-color="#626AEF"
                @confirm="handleDelete"
            >
              <template #reference>
                <el-button
                    type="danger"
                    plain
                    icon="Delete"
                    v-hasPermi="['basicData:license:remove']"
                >清除全表</el-button>
              </template>
            </el-popconfirm>
          </el-col>
          <el-col :span="1.5">
            <el-button
                type="danger"
                plain
                icon="Delete"
                @click="batchDelete"
                v-hasPermi="['basicData:license:remove']"
                :disabled="ids.length === 0"
            >批量删除</el-button>
          </el-col>
          <el-col :span="1.5">
            <el-button
                type="warning"
                plain
                icon="Download"
                @click="handleExport"
                :disabled="!summaryList.length"
                v-hasPermi="['basicData:summary:export']"
            >导出</el-button>
          </el-col>
          <el-col :span="1.5">
            <el-button type="info" plain icon="Upload" @click="handleImport"
                       v-hasPermi="['system:user:import']">导入
            </el-button>
          </el-col>
          <el-col :span="1.5">
            <el-button type="success" plain icon="Download" @click="downloadTemplate">
              下载导入模版
            </el-button>
          </el-col>
          <!--      <right-toolbar v-model:showSearch="showSearch" @queryTable="getList"></right-toolbar>-->
        </el-row>
      </el-form-item>
    </el-form>


    <el-table v-loading="loading" :data="summaryList" height="650" @selection-change="handleSelectionChange">
      <el-table-column type="selection" width="55" align="center" />
<!--      <el-table-column label="主键" align="center" prop="id" />-->
      <el-table-column label="企业名称" align="center" prop="enterpriseName" :show-overflow-tooltip="true" />
      <el-table-column label="统一社会信用代码" align="center" prop="unifiedSocialCreditCode" width="200" />
      <el-table-column label="是否属于国家级" align="center" prop="isNationalLevel" :show-overflow-tooltip="true" />
      <el-table-column label="实验室建设" align="center" prop="labConstruction" :show-overflow-tooltip="true" />
      <el-table-column label="政府资金支持" align="center" prop="governmentFundingSupport" :show-overflow-tooltip="true" />
      <el-table-column label="参与标准制定" align="center" prop="participationInStandards" :show-overflow-tooltip="true" />
      <el-table-column label="人才认证" align="center" prop="talentCertification" :show-overflow-tooltip="true" />
      <el-table-column label="其他" align="center" prop="otherRelatedActivities" :show-overflow-tooltip="true" />
<!--      <el-table-column label="操作" align="center" class-name="small-padding fixed-width">-->
<!--        <template #default="scope">-->
<!--          <el-button-->
<!--              type="text"-->
<!--              icon="Edit"-->
<!--              @click="handleUpdate(scope.row)"-->
<!--              v-hasPermi="['basicData:summary:edit']"-->
<!--          >修改</el-button>-->
<!--          <el-button-->
<!--              type="text"-->
<!--              icon="Delete"-->
<!--              @click="handleDelete(scope.row)"-->
<!--              v-hasPermi="['basicData:summary:remove']"-->
<!--          >删除</el-button>-->
<!--        </template>-->
<!--      </el-table-column>-->
    </el-table>

    <div style="position: fixed;bottom: 20px;right: 10px;">
      <pagination
          v-show="total>0"
          :total="total"
          v-model:page="queryParams.pageNum"
          v-model:limit="queryParams.pageSize"
          @pagination="getList"
      />
    </div>

    <el-dialog :title="upload.title" v-model="upload.open" width="400px" append-to-body>
      <el-upload ref="uploadRef" :limit="1" accept=".xlsx, .xls" :headers="upload.headers"
                 :action="upload.url + '?updateSupport=' + upload.updateSupport" :disabled="upload.isUploading"
                 :on-progress="handleFileUploadProgress" :on-success="handleFileSuccess" :auto-upload="false" drag>
        <el-icon class="el-icon--upload"><upload-filled /></el-icon>
        <div class="el-upload__text">将文件拖到此处，或<em>点击上传</em></div>
        <template #tip>
          <div class="el-upload__tip text-center">
            <span>仅允许导入xls、xlsx格式文件。</span>
          </div>
        </template>
      </el-upload>
      <template #footer>
        <div class="dialog-footer">
          <el-button type="primary" @click="submitFileForm">确 定</el-button>
          <el-button @click="upload.open = false">取 消</el-button>
        </div>
      </template>
    </el-dialog>

    <!-- 添加或修改企业科技研发信息汇总对话框 -->
  </div>
</template>

<script setup name="Summary">
import {listSummary, getSummary, delSummary, addSummary, updateSummary, delSummaryBatch} from "@/api/basicData/summary";
import {reactive} from "vue";
import {getToken} from "@/utils/auth";
import {ElMessage} from "element-plus";
import {likeQueryMethod} from "@/utils/likeQueryMethod";

const { proxy } = getCurrentInstance();

const summaryList = ref([]);
const open = ref(false);
const loading = ref(true);
const showSearch = ref(true);
const ids = ref([]);
const single = ref(true);
const multiple = ref(true);
const total = ref(0);
const title = ref("");

const upload = reactive({
  // 是否显示弹出层（用户导入）
  open: false,
  // 弹出层标题（用户导入）
  title: '',
  // 是否禁用上传
  isUploading: false,
  // 设置上传的请求头部
  headers: {Authorization: getToken()},
  // 上传的地址
  url: import.meta.env.VITE_APP_BASE_API + '/crmEnterpriseTechnologyRndSummary/importData'
})
const handleFileSuccess = (e)=>{
  if(e.code == 200){
    ElMessage({
      type:"success",
      message:e.msg
    })
    getList()
    proxy.$refs['uploadRef']?.clearFiles()
  }else {
    ElMessage({
      type:"error",
      message:e.msg
    })
    proxy.$refs['uploadRef']?.clearFiles()
  }
}
function submitFileForm() {
  proxy.$refs['uploadRef'].submit()
  upload.open = false;
  // setTimeout(getList,1000)
}
function handleImport() {
  upload.open = true
  // let toServerObj = likeQueryMethod('unified_social_credit_code', queryParams.value.unifiedSocialCreditCode, queryParams.value.pageNum, queryParams.value.pageSize,'enterprise_name',queryParams.value.enterpriseName);
  // listSummary(toServerObj).then(res=>{
  //   if(res.records.length >0){
  //     ElMessage({
  //       type:'warning',
  //       message:'当前已经有数据，请删除后再导入'
  //     })
  //     return
  //   }else {
  //     upload.title = '用户导入'
  //     upload.open = true
  //   }
  // })
}

const data = reactive({
  form: {},
  queryParams: {
    pageNum: 1,
    pageSize: 20,
    enterpriseName: null,
    unifiedSocialCreditCode: '',
    isNationalLevel: null,
    labConstruction: null,
    governmentFundingSupport: null,
    participationInStandards: null,
    talentCertification: null,
    otherRelatedActivities: null,
  },
  rules: {
  }
});

const { queryParams, form, rules } = toRefs(data);

/** 查询企业科技研发信息汇总列表 */
function getList() {
  loading.value = true;
  let toServerObj = likeQueryMethod('unified_social_credit_code', queryParams.value.unifiedSocialCreditCode, queryParams.value.pageNum, queryParams.value.pageSize,'enterprise_name',queryParams.value.enterpriseName);
  listSummary(toServerObj).then(response => {
    summaryList.value = response.records;
    total.value = response.total;
    loading.value = false;
  });
}

// 取消按钮
function cancel() {
  open.value = false;
  reset();
}

// 表单重置
function reset() {
  form.value = {
    id: null,
    enterpriseName: null,
    unifiedSocialCreditCode: '',
    isNationalLevel: null,
    labConstruction: null,
    governmentFundingSupport: null,
    participationInStandards: null,
    talentCertification: null,
    otherRelatedActivities: null,
    createTime: null,
    updateTime: null
  };
  proxy.resetForm("summaryRef");
}

/** 搜索按钮操作 */
function handleQuery() {
  queryParams.value.pageNum = 1;
  getList();
}

/** 重置按钮操作 */
function resetQuery() {
  proxy.resetForm("queryRef");
  handleQuery();
}

// 多选框选中数据
function handleSelectionChange(selection) {
  ids.value = selection.map(item => item.id);
  single.value = selection.length != 1;
  multiple.value = !selection.length;
}

/** 新增按钮操作 */
function handleAdd() {
  reset();
  open.value = true;
  title.value = "添加企业科技研发信息汇总";
}

/** 修改按钮操作 */
function handleUpdate(row) {
  reset();
  const id = row.id || ids.value
  getSummary(id).then(response => {
    form.value = response.data;
    open.value = true;
    title.value = "修改企业科技研发信息汇总";
  });
}

/** 提交按钮 */
function submitForm() {
  proxy.$refs["summaryRef"].validate(valid => {
    if (valid) {
      if (form.value.id != null) {
        updateSummary(form.value).then(response => {
          proxy.$modal.msgSuccess("修改成功");
          open.value = false;
          getList();
        });
      } else {
        addSummary(form.value).then(response => {
          proxy.$modal.msgSuccess("新增成功");
          open.value = false;
          getList();
        });
      }
    }
  });
}

/** 删除按钮操作 */
async function handleDelete(row) {
  const res = await delSummary();
  if(res.code == 200){
    ElMessage({
      type:'success',
      message:'删除成功'
    })
    getList();
  }
  // const ids = row.id || ids.value;
  // proxy.$modal.confirm('是否确认删除企业科技研发信息汇总编号为"' + ids + '"的数据项？').then(function() {
  //   return delSummary(ids);
  // }).then(() => {
  //   getList();
  //   proxy.$modal.msgSuccess("删除成功");
  // }).catch(() => {});
}
/**
 * 批量删除
 */
const batchDelete = (row)=>{
  const idsToS = row.id || ids.value;
  proxy.$modal.confirm('是否确认删除这'+idsToS.length+'条的数据项？').then(function() {
    return delSummaryBatch(toRaw(idsToS));
  }).then(() => {
    getList();
    proxy.$modal.msgSuccess("删除成功");
  }).catch(() => {});
}

/** 导出按钮操作 */
function handleExport() {
  proxy.download('crmEnterpriseTechnologyRndSummary/exportData', {
    ...queryParams.value
  }, `企业科技研发信息_${new Date().getTime()}.xlsx`)
}
const downloadTemplate = ()=>{
  proxy.download('crmEnterpriseTechnologyRndSummary/getUploadTemplate',{}, `企业科技研发信息模板.xlsx`)
}

getList();
</script>
